@@ -3,20 +3,8 @@
  *
  * Author: Jorn Baayen <jorn@openedhand.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
  */
 
 #ifndef GSSDP_CLIENT_H
@@ -39,6 +27,8 @@ typedef struct _GSSDPClientClass GSSDPClientClass;
  * @GSSDP_UDA_VERSION_UNSPECIFIED: When creating a client, use the default version
  * @GSSDP_UDA_VERSION_1_0: Use Version 1.0 of the UDA specification (UPnP/1.0)
  * @GSSDP_UDA_VERSION_1_1: Use Version 1.1 of the UDA specification (UPnP/1.1)
+ *
+ * Implemented behavior of the UDA (Unified Device Architecture) protocol.
  */
 typedef enum /*< prefix=GSSDP_UDA_ >*/
 {
@@ -98,6 +88,9 @@ gssdp_client_get_index        (GSSDPClient *client);
 GSocketFamily
 gssdp_client_get_family       (GSSDPClient *client);
 
+GInetAddressMask *
+gssdp_client_get_address_mask (GSSDPClient *client);
+
 void
 gssdp_client_append_header    (GSSDPClient *client,
                                const char  *name,
@@ -122,6 +115,18 @@ gssdp_client_guess_user_agent (GSSDPClient *client,
 GSSDPUDAVersion
 gssdp_client_get_uda_version  (GSSDPClient *client);
 
+void
+gssdp_client_set_boot_id      (GSSDPClient *client,
+                               gint32       boot_id);
+
+void
+gssdp_client_set_config_id    (GSSDPClient *client,
+                               gint32       config_id);
+
+gboolean
+gssdp_client_can_reach (GSSDPClient *client,
+                        GInetSocketAddress *address);
+
 G_END_DECLS
 
 #endif /* GSSDP_CLIENT_H */
