@@ -3,27 +3,13 @@
  *
  * Author: Jens Georg <mail@jensge.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
  */
 
 #define G_LOG_DOMAIN "gssdp-net"
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif /* HAVE_CONFIG_H */
 
 #include "gssdp-net.h"
 
@@ -58,7 +44,13 @@ int
 gssdp_net_query_ifindex (GSSDPNetworkDevice *device)
 {
 #if defined(HAVE_IFNAMETOINDEX)
-    return if_nametoindex (device->iface_name);
+        errno = 0;
+        int index = if_nametoindex (device->iface_name);
+        if (index == 0 && errno != 0) {
+                return -1;
+        } else {
+                return index;
+        }
 
 #elif defined(HAVE_SIOCGIFINDEX)
     int fd;
@@ -209,7 +201,14 @@ gssdp_net_mac_lookup (GSSDPNetworkDevice *device, const char *ip_address)
                                 } else if (rtattr->rta_type == NDA_LLADDR) {
                                         g_clear_pointer (&data, g_free);
                                         data_length = RTA_PAYLOAD (rtattr);
+#if GLIB_CHECK_VERSION(2, 68, 0)
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+                                        data = g_memdup2 (RTA_DATA (rtattr), data_length);
+#pragma GCC diagnostic pop
+#else
                                         data = g_memdup (RTA_DATA (rtattr), data_length);
+#endif
                                 }
 
                                 rtattr = RTA_NEXT (rtattr, rtattr_len);
@@ -455,7 +454,7 @@ gssdp_net_get_host_ip (GSSDPNetworkDevice *device)
         /*
          * Now go through the devices we consider worthy
          */
-        family = G_SOCKET_FAMILY_INVALID;
+        family = device->address_family;
 
         /* If we have an address, its family will take precendence.
          * Otherwise take the family from the client's config
@@ -473,8 +472,6 @@ gssdp_net_get_host_ip (GSSDPNetworkDevice *device)
                         g_free (addr);
                         g_clear_object (&device->host_addr);
                 }
-        } else {
-                family = device->address_family;
         }
 
         for (ifaceptr = up_ifaces;
