@@ -3,20 +3,8 @@
  *
  * Author: Jens Georg <jensg@openismus.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
  */
 
 #define UUID_1 "uuid:81909e94-ebf4-469e-ac68-81f2f189de1b"
@@ -28,6 +16,7 @@
 
 #include <gio/gio.h>
 
+#include <libgssdp/gssdp-error.h>
 #include <libgssdp/gssdp-resource-browser.h>
 #include <libgssdp/gssdp-resource-group.h>
 #include <libgssdp/gssdp-protocol.h>
@@ -242,6 +231,9 @@ static void test_bgo682099 (void)
         g_idle_add (unref_object, browser);
         g_timeout_add_seconds (10, quit_loop, loop);
         g_main_loop_run (loop);
+        g_signal_handler_disconnect (browser, signal_id);
+        g_object_unref (browser);
+        g_main_loop_unref (loop);
 }
 
 /* END Regression test
@@ -362,7 +354,8 @@ static void test_bgo724030 (void)
                                       loop);
         g_main_loop_run (loop);  /* unavailable + available */
         g_main_loop_run (loop);  /* unavailable */
-        unref_object(browser);
+        g_signal_handler_disconnect (browser, available_signal_id);
+        g_object_unref (browser);
 }
 
 /* END Regression test
@@ -413,6 +406,63 @@ static void test_ggo_1(void)
  * ============================================================================
  */
 
+/* BEGIN Regression test
+ * https://gitlab.gnome.org/GNOME/gssdp/issues/7
+ * ============================================================================
+ *  - Check that creating a GSSDPClient with interface and ip will have a set
+ *    network mask
+ */
+void test_ggo_7 () {
+        GError *error = NULL;
+
+
+
+        // Detect the name of the adapter belonging to 127.0.0.1
+        // Yes, this is awkward, but on Windows I believe the GUID is unique for
+        // the system, but not the same on every windows and *BSD is different to
+        // Linux as well (lo0 vs lo)
+        GSSDPClient *client = g_initable_new (GSSDP_TYPE_CLIENT,
+                                              NULL,
+                                              &error,
+                                              "host-ip", "127.0.0.1",
+                                              NULL);
+        g_assert_no_error (error);
+        g_assert_nonnull (client);
+
+        char *iface = g_strdup (gssdp_client_get_interface (client));
+        g_clear_object (&client);
+
+        g_debug("Found adapter %s for 127.0.0.1", iface);
+
+        // Check that trying to get a client for a non-existing interface fails
+        client = g_initable_new (GSSDP_TYPE_CLIENT,
+                                 NULL,
+                                 &error,
+                                 "host-ip", "127.0.0.1",
+                                 "interface", "ThisShouldNotExist",
+                                 NULL);
+        g_assert_error (error, GSSDP_ERROR, GSSDP_ERROR_FAILED);
+        g_assert_null (client);
+        g_clear_error (&error);
+
+        client = g_initable_new (GSSDP_TYPE_CLIENT,
+                                 NULL,
+                                 &error,
+                                 "host-ip", "127.0.0.1",
+                                 "interface", iface,
+                                 NULL);
+        g_assert_no_error (error);
+        g_assert_nonnull (client);
+        g_assert_nonnull (gssdp_client_get_address_mask (client));
+
+        g_free (iface);
+}
+
+/* END Regression test
+ * https://gitlab.gnome.org/GNOME/gssdp/issues/7
+ * ============================================================================
+ */
+
 
 int main (int argc, char *argv[])
 {
@@ -427,6 +477,7 @@ int main (int argc, char *argv[])
                g_test_add_func ("/bugs/gnome/724030", test_bgo724030);
                g_test_add_func ("/bugs/ggo/1", test_ggo_1);
         }
+        g_test_add_func ("/bugs/ggo/7", test_ggo_7);
 
         g_test_run ();
 
